window.Gleam.initSearch([{"doc":"cachmere","title":"cachmere","content":"# cachmere\n\n[![Package Version](https://img.shields.io/hexpm/v/cachmere)](https://hex.pm/packages/cachmere)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/cachmere/)\n\nA caching solution for Gleam web apps, designed to be used with Wisp. Currently\na work-in-progress. Breaking changes may be made to the API.\n\nThe goal with `cachmere` is to provide more control over the static assets you\nhave to serve from your backend.\n\n### Use Case\n\nSome times you want to have the browser cache statically served assets. This is\ndesierable for a number of reasons, such as increasing page load times, as the\nbrowser already has the files, and saving server bandwith.\n\nOne such scenario could be, you have a SPA (single page application) built using\na modern javascript framework and you are serving it from your backend. The\ninitial download might be big, so having the browser cache the unchanged files\ncould drastically improve page load times after initial load.\n\n#### Custom Response Headers\n\nIf you use a modern build tool, such as vite, your files can be fingerprinted\nwith unique names that change when the content changes. In this case, you can\nset the Cache-Control header in the server response to cache your files for the\nlongest possible time.\n\n#### ETags\n\nIf you don&#39;t have file fingerprinting or aren&#39;t using a build tool at all, you\ncould enable ETags. This will allow the browser to cache the file and ask the\nserver if the file has changed. This option will result in more server requests\nthan the latter but will still save you bandwith as the server will only return\nthe file if the etag has changed. If the file hasn&#39;t been updated, the server\nwill return a 304 Not Modified response.\n\nFor more details and code examples, see the [docs](cachmere.html).\n\n## Development\n\n```sh\nmise up # install development environment dependencies\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"cachmere","title":"ServeStaticOptions","content":"pub type ServeStaticOptions {\n  ServeStaticOptions(\n    etags: Bool,\n    response_headers: List(#(String, String)),\n    file_types: List(String),\n  )\n}\n Options for `serve_static_with`.\n\n - `etags` is a boolean that enables the use of entity tags. Enabling this will generate etags for all files served\n from the location passed to `serve_static_with`.\n - `response_headers` is a list of response headers, in a tuple format. eg. &quot;cache-control&quot;: &quot;max-age=31536000&quot;.\n - `file_types` is a list of file types to apply the defined response headers to.\n This allows you to control the headers, such as cache-control, on a per file type basis.\n Unlisted file types will still be served but they won&#39;t have the headers defined in `response_headers` applied to them.\n An empty list will result in identical behaviour to `serve_static`.\n\nServeStaticOptions(\n  etags: Bool,\n  response_headers: List(#(String, String)),\n  file_types: List(String),\n)\n\n\nSynonyms:\ncachmere.ServeStaticOptions\ncachmere ServeStaticOptions","url":"cachmere.html#ServeStaticOptions"},{"doc":"cachmere","title":"default_cache_settings","content":"pub fn default_cache_settings() -&gt; ServeStaticOptions\n Returns `ServeStaticOptions` with a default config for caching\n\n # Default Settings\n \n ServeStaticOptions(\n   etags: False,\n   file_types: [&quot;js&quot;, &quot;css&quot;],\n   response_headers: [#(&quot;cache-control&quot;, &quot;max-age=31536000, immutable&quot;)]\n )\n \n\nSynonyms:\ncachmere.default_cache_settings\ncachmere default_cache_settings","url":"cachmere.html#default_cache_settings"},{"doc":"cachmere","title":"serve_static","content":"pub fn serve_static(\n  req: Request(Connection),\n  under prefix: String,\n  from directory: String,\n  next handler: fn() -&gt; Response(Body),\n) -&gt; Response(Body)\n A middleware function that serves files from a directory, along with a\n suitable `content-type` header for known file extensions.\n\n Files are sent using the `File` response body type, so they will be sent\n directly to the client from the disc, without being read into memory.\n\n The `under` parameter is the request path prefix that must match for the\n file to be served.\n\n | `under`   | `from`  | `request.path`     | `file`                  |\n |-----------|---------|--------------------|-------------------------|\n | `/static` | `/data` | `/static/file.txt` | `/data/file.txt`        |\n | ``        | `/data` | `/static/file.txt` | `/data/static/file.txt` |\n | `/static` | ``      | `/static/file.txt` | `file.txt`              |\n\n This middleware will discard any `..` path segments in the request path to\n prevent the client from accessing files outside of the directory. It is\n advised not to serve a directory that contains your source code, application\n configuration, database, or other private files.\n\n # Examples\n\n \n fn handle_request(req: Request) -&gt; Response {\n   use &lt;- cachmere.serve_static(req, under: &quot;/static&quot;, from: &quot;/public&quot;)\n   // ...\n }\n \n\n Typically your static assets may be kept in your project in a directory\n called `priv`. The `priv_directory` function can be used to get a path to\n this directory.\n\n \n fn handle_request(req: Request) -&gt; Response {\n   let assert Ok(priv) = priv_directory(&quot;my_application&quot;)\n   use &lt;- cachmere.serve_static(req, under: &quot;/static&quot;, from: priv)\n   // ...\n }\n \n\nSynonyms:\ncachmere.serve_static\ncachmere serve_static","url":"cachmere.html#serve_static"},{"doc":"cachmere","title":"serve_static_with","content":"pub fn serve_static_with(\n  req: Request(Connection),\n  under prefix: String,\n  from directory: String,\n  options options: ServeStaticOptions,\n  next handler: fn() -&gt; Response(Body),\n) -&gt; Response(Body)\n Functions the same as `serve_static` but takes options for enabling etags and setting response headers for specific file types.\n This allows for configuring headers such as Cache-Control etc.\n\n # Examples\n Serve files from static folder and apply cache-control header to `.js` and `.css` files.\n All other file will be served but they won&#39;t have the defined response headers added to them.\n \n fn handle_request(req: Request) -&gt; Response {\n   let assert Ok(priv) = priv_directory(&quot;my_application&quot;)\n   use &lt;- cachmere.serve_static_with(\n     req,\n     under: &quot;/static&quot;,\n     from: priv,\n     options: cachmere.ServeStaticOptions(\n       etags: False,\n       file_types: [&quot;js&quot;, &quot;css&quot;],\n       response_headers: [#(&quot;cache-control&quot;, &quot;max-age=31536000, immutable&quot;)],\n     ),\n   )\n   // ...\n }\n \n\n Serve files from static folder using etags. If files have not been edited, `serve_static_with`\n will return a status 304 allowing the browser to use the cached version of the file.\n \n fn handle_request(req: Request) -&gt; Response {\n   let assert Ok(priv) = priv_directory(&quot;my_application&quot;)\n   use &lt;- cachmere.serve_static_with(\n     req,\n     under: &quot;/static&quot;,\n     from: priv,\n     options: cachmere.ServeStaticOptions(\n       etags: True,\n       file_types: [],\n       response_headers: [],\n     ),\n   )\n   // ...\n }\n \n\nSynonyms:\ncachmere.serve_static_with\ncachmere serve_static_with","url":"cachmere.html#serve_static_with"},{"doc":"cachmere","title":"cachmere","content":"","url":"cachmere.html"}]);